Documentation
¶
Overview ¶
Package omap provides an ordered map implementation.
Index ¶
- func Init(cfg PoolConfig)
- type Buffer
- func (b *Buffer) AppendByte(data byte)
- func (b *Buffer) AppendBytes(data []byte)
- func (b *Buffer) AppendString(data string)
- func (b *Buffer) BuildBytes(reuse ...[]byte) []byte
- func (b *Buffer) DumpTo(w io.Writer) (written int, err error)
- func (b *Buffer) EnsureSpace(s int)
- func (b *Buffer) ReadCloser() io.ReadCloser
- func (b *Buffer) Size() int
- type Flags
- type InitOption
- type KeyNotFoundError
- type OrderedMap
- func (om *OrderedMap[K, V]) AddPairs(pairs ...Pair[K, V])
- func (om *OrderedMap[K, V]) Delete(key K) (val V, present bool)
- func (om *OrderedMap[K, V]) Get(key K) (val V, present bool)
- func (om *OrderedMap[K, V]) GetAndMoveToBack(key K) (val V, err error)
- func (om *OrderedMap[K, V]) GetAndMoveToFront(key K) (val V, err error)
- func (om *OrderedMap[K, V]) GetPair(key K) *Pair[K, V]
- func (om *OrderedMap[K, V]) Len() int
- func (om *OrderedMap[K, V]) Load(key K) (V, bool)
- func (om *OrderedMap[K, V]) MarshalJSON() ([]byte, error)
- func (om *OrderedMap[K, V]) MoveAfter(key, markKey K) error
- func (om *OrderedMap[K, V]) MoveBefore(key, markKey K) error
- func (om *OrderedMap[K, V]) MoveToBack(key K) error
- func (om *OrderedMap[K, V]) MoveToFront(key K) error
- func (om *OrderedMap[K, V]) Newest() *Pair[K, V]
- func (om *OrderedMap[K, V]) Oldest() *Pair[K, V]
- func (om *OrderedMap[K, V]) Set(key K, value V) (val V, present bool)
- func (om *OrderedMap[K, V]) Store(key K, value V) (V, bool)
- func (om *OrderedMap[K, V]) UnmarshalJSON(data []byte) error
- func (om *OrderedMap[K, V]) Value(key K) (val V)
- type Pair
- type PoolConfig
- type Writer
- func (w *Writer) Base64Bytes(data []byte)
- func (w *Writer) Bool(v bool)
- func (w *Writer) BuildBytes(reuse ...[]byte) ([]byte, error)
- func (w *Writer) DumpTo(out io.Writer) (written int, err error)
- func (w *Writer) Float32(n float32)
- func (w *Writer) Float32Str(n float32)
- func (w *Writer) Float64(n float64)
- func (w *Writer) Float64Str(n float64)
- func (w *Writer) Int(n int)
- func (w *Writer) Int8(n int8)
- func (w *Writer) Int8Str(n int8)
- func (w *Writer) Int16(n int16)
- func (w *Writer) Int16Str(n int16)
- func (w *Writer) Int32(n int32)
- func (w *Writer) Int32Str(n int32)
- func (w *Writer) Int64(n int64)
- func (w *Writer) Int64Str(n int64)
- func (w *Writer) IntStr(n int)
- func (w *Writer) Raw(data []byte, err error)
- func (w *Writer) RawByte(c byte)
- func (w *Writer) RawString(s string)
- func (w *Writer) RawText(data []byte, err error)
- func (w *Writer) ReadCloser() (io.ReadCloser, error)
- func (w *Writer) Size() int
- func (w *Writer) String(s string)
- func (w *Writer) Uint(n uint)
- func (w *Writer) Uint8(n uint8)
- func (w *Writer) Uint8Str(n uint8)
- func (w *Writer) Uint16(n uint16)
- func (w *Writer) Uint16Str(n uint16)
- func (w *Writer) Uint32(n uint32)
- func (w *Writer) Uint32Str(n uint32)
- func (w *Writer) Uint64(n uint64)
- func (w *Writer) Uint64Str(n uint64)
- func (w *Writer) UintStr(n uint)
- func (w *Writer) UintptrStr(n uintptr)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Init ¶
func Init(cfg PoolConfig)
Init sets up a non-default pooling and allocation strategy. Should be run before serialization is done.
Types ¶
type Buffer ¶
type Buffer struct {
// Buf is the current chunk that can be used for serialization.
Buf []byte
// contains filtered or unexported fields
}
Buffer is a buffer optimized for serialization without extra copying.
func (*Buffer) AppendByte ¶
AppendByte appends a single byte to buffer.
func (*Buffer) AppendBytes ¶
AppendBytes appends a byte slice to buffer.
func (*Buffer) AppendString ¶
AppendString appends a string to buffer.
func (*Buffer) BuildBytes ¶
BuildBytes creates a single byte slice with all the contents of the buffer. Data is copied if it does not fit in a single chunk. You can optionally provide one byte slice as argument that it will try to reuse.
func (*Buffer) EnsureSpace ¶
EnsureSpace makes sure that the current chunk contains at least s free bytes, possibly creating a new chunk.
func (*Buffer) ReadCloser ¶
func (b *Buffer) ReadCloser() io.ReadCloser
ReadCloser creates an io.ReadCloser with all the contents of the buffer.
type Flags ¶
type Flags int
Flags describe various encoding options. The behavior may be actually implemented in the encoder, but Flags field in Writer is used to set and pass them around.
type InitOption ¶
type InitOption[K comparable, V any] func(config *initConfig[K, V])
InitOption is an option for initializing an OrderedMap.
func WithCapacity ¶
func WithCapacity[K comparable, V any](capacity int) InitOption[K, V]
WithCapacity allows giving a capacity hint for the map, akin to the standard make(map[K]V, capacity).
func WithInitialData ¶
func WithInitialData[K comparable, V any](initialData ...Pair[K, V]) InitOption[K, V]
WithInitialData allows passing in initial data for the map.
type KeyNotFoundError ¶
type KeyNotFoundError[K comparable] struct { MissingKey K }
KeyNotFoundError may be returned by functions in this package when they're called with keys that are not present in the map.
func (*KeyNotFoundError[K]) Error ¶
func (e *KeyNotFoundError[K]) Error() string
type OrderedMap ¶
type OrderedMap[K comparable, V any] struct { // contains filtered or unexported fields }
OrderedMap is a generic ordered map.
func New ¶
func New[K comparable, V any](options ...any) *OrderedMap[K, V]
New creates a new OrderedMap. options can either be one or several InitOption[K, V], or a single integer, which is then interpreted as a capacity hint, à la make(map[K]V, capacity).
func (*OrderedMap[K, V]) AddPairs ¶
func (om *OrderedMap[K, V]) AddPairs(pairs ...Pair[K, V])
AddPairs allows setting multiple pairs at a time. It's equivalent to calling Set on each pair sequentially.
func (*OrderedMap[K, V]) Delete ¶
func (om *OrderedMap[K, V]) Delete(key K) (val V, present bool)
Delete removes the key-value pair, and returns what `Get` would have returned on that key prior to the call to `Delete`.
func (*OrderedMap[K, V]) Get ¶
func (om *OrderedMap[K, V]) Get(key K) (val V, present bool)
Get looks for the given key, and returns the value associated with it, or V's nil value if not found. The boolean it returns says whether the key is present in the map.
func (*OrderedMap[K, V]) GetAndMoveToBack ¶
func (om *OrderedMap[K, V]) GetAndMoveToBack(key K) (val V, err error)
GetAndMoveToBack combines Get and MoveToBack in the same call. If an error is returned, it will be a KeyNotFoundError.
func (*OrderedMap[K, V]) GetAndMoveToFront ¶
func (om *OrderedMap[K, V]) GetAndMoveToFront(key K) (val V, err error)
GetAndMoveToFront combines Get and MoveToFront in the same call. If an error is returned, it will be a KeyNotFoundError.
func (*OrderedMap[K, V]) GetPair ¶
func (om *OrderedMap[K, V]) GetPair(key K) *Pair[K, V]
GetPair looks for the given key, and returns the pair associated with it, or nil if not found. The Pair struct can then be used to iterate over the ordered map from that point, either forward or backward.
func (*OrderedMap[K, V]) Len ¶
func (om *OrderedMap[K, V]) Len() int
Len returns the length of the ordered map.
func (*OrderedMap[K, V]) Load ¶
func (om *OrderedMap[K, V]) Load(key K) (V, bool)
Load is an alias for Get, mostly to present an API similar to `sync.Map`'s.
func (*OrderedMap[K, V]) MarshalJSON ¶
func (om *OrderedMap[K, V]) MarshalJSON() ([]byte, error)
MarshalJSON implements the json.Marshaler interface.
func (*OrderedMap[K, V]) MoveAfter ¶
func (om *OrderedMap[K, V]) MoveAfter(key, markKey K) error
MoveAfter moves the value associated with key to its new position after the one associated with markKey. Returns an error iff key or markKey are not present in the map. If an error is returned, it will be a KeyNotFoundError.
func (*OrderedMap[K, V]) MoveBefore ¶
func (om *OrderedMap[K, V]) MoveBefore(key, markKey K) error
MoveBefore moves the value associated with key to its new position before the one associated with markKey. Returns an error iff key or markKey are not present in the map. If an error is returned, it will be a KeyNotFoundError.
func (*OrderedMap[K, V]) MoveToBack ¶
func (om *OrderedMap[K, V]) MoveToBack(key K) error
MoveToBack moves the value associated with key to the back of the ordered map, i.e. makes it the newest pair in the map. Returns an error iff key is not present in the map. If an error is returned, it will be a KeyNotFoundError.
func (*OrderedMap[K, V]) MoveToFront ¶
func (om *OrderedMap[K, V]) MoveToFront(key K) error
MoveToFront moves the value associated with key to the front of the ordered map, i.e. makes it the oldest pair in the map. Returns an error iff key is not present in the map. If an error is returned, it will be a KeyNotFoundError.
func (*OrderedMap[K, V]) Newest ¶
func (om *OrderedMap[K, V]) Newest() *Pair[K, V]
Newest returns a pointer to the newest pair. It's meant to be used to iterate on the ordered map's pairs from the newest to the oldest, e.g.: for pair := orderedMap.Oldest(); pair != nil; pair = pair.Next() { fmt.Printf("%v => %v\n", pair.Key, pair.Value) }
func (*OrderedMap[K, V]) Oldest ¶
func (om *OrderedMap[K, V]) Oldest() *Pair[K, V]
Oldest returns a pointer to the oldest pair. It's meant to be used to iterate on the ordered map's pairs from the oldest to the newest, e.g.: for pair := orderedMap.Oldest(); pair != nil; pair = pair.Next() { fmt.Printf("%v => %v\n", pair.Key, pair.Value) }
func (*OrderedMap[K, V]) Set ¶
func (om *OrderedMap[K, V]) Set(key K, value V) (val V, present bool)
Set sets the key-value pair, and returns what `Get` would have returned on that key prior to the call to `Set`.
func (*OrderedMap[K, V]) Store ¶
func (om *OrderedMap[K, V]) Store(key K, value V) (V, bool)
Store is an alias for Set, mostly to present an API similar to `sync.Map`'s.
func (*OrderedMap[K, V]) UnmarshalJSON ¶
func (om *OrderedMap[K, V]) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the json.Unmarshaler interface.
func (*OrderedMap[K, V]) Value ¶
func (om *OrderedMap[K, V]) Value(key K) (val V)
Value returns the value associated with the given key or the zero value.
type Pair ¶
type Pair[K comparable, V any] struct { Key K Value V // contains filtered or unexported fields }
Pair is a generic pair.
type PoolConfig ¶
type PoolConfig struct {
StartSize int // Minimum chunk size that is allocated.
PooledSize int // Minimum chunk size that is reused, reusing chunks too small will result in overhead.
MaxSize int // Maximum chunk size that will be allocated.
}
PoolConfig contains configuration for the allocation and reuse strategy.
type Writer ¶
Writer is a JSON writer.
func (*Writer) Base64Bytes ¶
Base64Bytes appends data to the buffer after base64 encoding it
func (*Writer) BuildBytes ¶
BuildBytes returns writer data as a single byte slice. You can optionally provide one byte slice as argument that it will try to reuse.
func (*Writer) Float32Str ¶
Float32Str appends a float32 to the buffer as a quoted string.
func (*Writer) Float64Str ¶
Float64Str appends a float64 to the buffer as a quoted string.
func (*Writer) Raw ¶
Raw appends raw binary data to the buffer or sets the error if it is given. Useful for calling with results of MarshalJSON-like functions.
func (*Writer) RawText ¶
RawText encloses raw binary data in quotes and appends in to the buffer. Useful for calling with results of MarshalText-like functions.
func (*Writer) ReadCloser ¶
func (w *Writer) ReadCloser() (io.ReadCloser, error)
ReadCloser returns an io.ReadCloser that can be used to read the data. ReadCloser also resets the buffer.
func (*Writer) UintptrStr ¶
UintptrStr appends an uintptr to the buffer as a quoted string.